@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.7.1
+Version : 1.8.0
 Author  : Stefano Covino
-Date    : 16/07/2014
+Date    : 30/10/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -36,6 +36,7 @@ History : (27/09/2010) First version.
         : (03/09/2013) Better search of catalogue objects.
         : (16/10/2013) Better computation of frame center.
         : (16/07/2014) Deal with non standard FITS headers.
+        : (30/10/2014) Sextractor source finding.
 """
 
 
@@ -197,6 +198,7 @@ class Astrometry:
             # Algorithms
             self.NativeSources = False
             self.EclipseSources = False
+            self.SexSources = False
             #
             self.DefineWCSHeader()
   
@@ -227,6 +229,7 @@ class Astrometry:
                     self.List = self.FitsFrame.List
             self.NativeSources = True
             self.EclipseSources = False
+            self.SexSources = False
 
 
     def GetEclipseSources(self, maxobjs=15, thre=22, cleanperc=1.):
@@ -249,9 +252,31 @@ class Astrometry:
                     self.List = self.FitsFrame.List
             self.EclipseSources = True
             self.NativeSources = False
+            self.SexSources = False
+
+
+
+    def GetSexSources(self, maxobjs=15, thre=10, cleanperc=1.):
+            soglia = copy.copy(thre)
+            while len(self.List) < maxobjs and soglia > 0.1:
+                self.FitsFrame.SexSources(soglia)
+                self.FitsFrame.CleanBorderSources(cleanperc)
+                self.FitsFrame.SortSourceList()
+                if len(self.FitsFrame.List) >= maxobjs:
+                    self.List = self.FitsFrame.List[:maxobjs]
+                else:
+                    if soglia-1 > 3:
+                        soglia = soglia - 1
+                    elif 1 < soglia <= 3:
+                        soglia = soglia - 0.5
+                    else:
+                        soglia = soglia - 0.1
+                    self.List = self.FitsFrame.List
+            self.SexSources = True
+            self.NativeSources = False
+            self.EclipseSources = False
 
 
-                    
     def GetCatSources(self, maxentr=15, catq='N'): 
             radius = 1.5*self.HalfSize*60.0  # arcmin
             #cntfld = (self.RA,self.DEC)
@@ -377,6 +402,11 @@ class Astrometry:
                 objlist.append(((i.X-self.CRPIX1),(i.Y-self.CRPIX2)))
                 #print objlist[-1]
                 #print i.flux
+        elif self.SexSources:
+            for i in self.List:
+                objlist.append(((i.X-self.CRPIX1),(i.Y-self.CRPIX2)))
+                #print objlist[-1]
+                #print i.flux
         #print 
         radec = []
         for i in self.CatList:
@@ -400,7 +430,9 @@ class Astrometry:
                 if self.NativeSources:
                     mtchinplist.append((self.List[i][0],self.List[i][1]))
                 elif self.EclipseSources:
-                    mtchinplist.append((self.List[i].X,self.List[i].Y))                
+                    mtchinplist.append((self.List[i].X,self.List[i].Y))
+                elif self.SexSources:
+                    mtchinplist.append((self.List[i].X,self.List[i].Y))
             for i in mtchres[1]:
                 mtchoutlist.append((self.CatList[i].RA,self.CatList[i].DEC))
             self.NStarRes = len(mtchres[0])
