@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.46
+Version : 1.1.49
 Author  : Stefano Covino
-Date    : 06/08/2014
+Date    : 04/11/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -121,6 +121,9 @@ History : (28/09/2010) First named version.
         : (21/07/2014) V. 3.11.1b4.
         : (02/08/2014) V. 3.12.0b1.
         : (06/08/2014) V. 3.12.0.
+        : (27/10/2014) V. 3.12.1b1.
+        : (30/10/2014) V. 3.12.1b2.
+        : (04/11/2014) V. 3.12.1.
 """
 
 
@@ -135,6 +138,6 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.12.0'
+__version__ = '3.12.1'
 
 #
\ No newline at end of file
